@@ -5,6 +5,7 @@ use crossterm::event;
 use ratatui::{
     backend::Backend,
     layout::Rect,
+    style::Style,
     text::{Line, Text},
     widgets::{Block, Borders, Clear, ScrollbarOrientation, ScrollbarState},
 };
@@ -12,12 +13,14 @@ use termbg::Theme;
 
 use super::{
     asm::assembly_line::AssemblyLine,
+    comments::Comments,
     data::Data,
     files::filesystem::FileSystem,
     frame_info::{FrameInfo, InfoViewFrameInfo},
     help::HelpLine,
     info_mode::InfoMode,
     log::{logger::Logger, NotificationLevel},
+    pane::Pane,
     plugins::plugin_manager::PluginManager,
     popup::popup_state::PopupState,
     settings::{color_settings::ColorSettings, Settings},
@@ -33,12 +36,15 @@ pub struct App {
     pub(super) logger: Logger,
     pub(super) help_list: Vec<HelpLine>,
     pub(super) data: Data,
+    pub(super) comments: Comments,
     pub(super) assembly_offsets: Vec<usize>,
     pub(super) assembly_instructions: Vec<AssemblyLine>,
     pub(super) text_last_searched_string: String,
     pub(super) info_mode: InfoMode,
     pub(super) scroll: usize,
     pub(super) cursor: (u16, u16),
+    pub(super) selected_pane: Pane,
+    pub(super) fullscreen: bool,
     pub(super) poll_time: Duration,
     pub(super) needs_to_exit: bool,
     pub(super) screen_size: (u16, u16),
@@ -99,6 +105,10 @@ impl App {
             .map(|s| (s.width, s.height))
     }
 
+    pub(super) fn switch_fullscreen(&mut self) {
+        self.fullscreen = !self.fullscreen;
+    }
+
     pub fn new<B: Backend>(
         args: Args,
         terminal: &mut ratatui::Terminal<B>,
@@ -178,24 +188,45 @@ impl App {
         terminal: &mut ratatui::Terminal<B>,
     ) -> Result<(), Box<dyn std::error::Error>> {
         terminal.draw(|f| {
+            let screen_size = (f.area().width, f.area().height);
+            self.resize_to_size(screen_size.0, screen_size.1);
+
             let min_width = self.block_size as u16 * 3 + 17 + 3;
             if f.area().width < min_width {
                 return;
             }
             let status_rect = Rect::new(0, f.area().height - 1, f.area().width, 1);
             let address_rect = Rect::new(0, 0, 17, f.area().height - status_rect.height);
-            let hex_editor_rect = Rect::new(
-                address_rect.width,
-                0,
-                (self.block_size * 3 * self.blocks_per_row + self.blocks_per_row) as u16,
-                f.area().height - status_rect.height,
-            );
-            let info_view_rect = Rect::new(
-                address_rect.width + hex_editor_rect.width,
-                0,
-                f.area().width - hex_editor_rect.width - address_rect.width - 2,
-                f.area().height - status_rect.height,
-            );
+            let hex_editor_rect: Rect;
+            let info_view_rect: Rect;
+            if self.fullscreen {
+                hex_editor_rect = Rect::new(
+                    address_rect.width,
+                    0,
+                    f.area().width - address_rect.width - 2,
+                    f.area().height - status_rect.height,
+                );
+                info_view_rect = Rect::new(
+                    address_rect.width,
+                    0,
+                    f.area().width - address_rect.width - 2,
+                    f.area().height - status_rect.height,
+                );
+            } else {
+                hex_editor_rect = Rect::new(
+                    address_rect.width,
+                    0,
+                    (self.block_size * 3 * self.blocks_per_row + self.blocks_per_row) as u16,
+                    f.area().height - status_rect.height,
+                );
+                info_view_rect = Rect::new(
+                    address_rect.width + hex_editor_rect.width,
+                    0,
+                    f.area().width - hex_editor_rect.width - address_rect.width - 2,
+                    f.area().height - status_rect.height,
+                );
+            }
+
             let scrollbar_rect = Rect::new(f.area().width - 1, 0, 1, f.area().height);
 
             let status_block = ratatui::widgets::Paragraph::new(self.build_status_bar())
@@ -228,12 +259,29 @@ impl App {
                 let editor_title =
                     format!("Hex Editor{}", if self.data.dirty() { " *" } else { "" });
 
+                let hex_border_style: Style;
+                let pretty_border_style: Style;
+                if self.selected_pane == Pane::Hex {
+                    hex_border_style = self.settings.color.pane_selected;
+                    pretty_border_style = self.settings.color.pane;
+                } else {
+                    hex_border_style = self.settings.color.pane;
+                    pretty_border_style = self.settings.color.pane_selected;
+                }
+
                 let hex_editor_block = ratatui::widgets::Paragraph::new(hex_view).block(
                     Block::default()
                         .title(editor_title)
-                        .borders(Borders::LEFT | Borders::TOP | Borders::RIGHT),
+                        .borders(Borders::LEFT | Borders::TOP | Borders::RIGHT)
+                        .border_style(hex_border_style),
                 );
 
+                let info_view_block_flags = if self.fullscreen {
+                    Borders::TOP | Borders::RIGHT | Borders::LEFT
+                } else {
+                    Borders::TOP | Borders::RIGHT
+                };
+
                 let info_view_block = match &self.info_mode {
                     InfoMode::Text => {
                         let text_subview_lines =
@@ -246,7 +294,8 @@ impl App {
                         ratatui::widgets::Paragraph::new(text_subview).block(
                             Block::default()
                                 .title("Text View")
-                                .borders(Borders::TOP | Borders::RIGHT),
+                                .borders(info_view_block_flags)
+                                .border_style(pretty_border_style),
                         )
                     }
                     InfoMode::Assembly => {
@@ -273,19 +322,28 @@ impl App {
                                     self.get_cursor_position().global_byte_index,
                                     &self.header,
                                     address_min_width,
+                                    &self.comments,
                                 )
                             }));
                         ratatui::widgets::Paragraph::new(assembly_subview).block(
                             Block::default()
                                 .title("Assembly View")
-                                .borders(Borders::TOP | Borders::RIGHT),
+                                .borders(info_view_block_flags)
+                                .border_style(pretty_border_style),
                         )
                     }
                 };
 
                 f.render_widget(address_block, address_rect);
-                f.render_widget(hex_editor_block, hex_editor_rect);
-                f.render_widget(info_view_block, info_view_rect);
+                if self.fullscreen {
+                    match self.selected_pane {
+                        Pane::Hex => f.render_widget(hex_editor_block, hex_editor_rect),
+                        Pane::View => f.render_widget(info_view_block, info_view_rect),
+                    }
+                } else {
+                    f.render_widget(hex_editor_block, hex_editor_rect);
+                    f.render_widget(info_view_block, info_view_rect);
+                }
             }
             f.render_widget(status_block, status_rect);
             f.render_stateful_widget(scrollbar, scrollbar_rect, &mut scrollbar_state);
@@ -295,8 +353,18 @@ impl App {
                 status_bar: status_rect,
                 scroll_bar: scrollbar_rect,
                 address_view: address_rect,
-                hex_view: hex_editor_rect,
-                info_view: info_view_rect,
+                hex_view: if !self.fullscreen || self.selected_pane == Pane::Hex {
+                    Some(hex_editor_rect)
+                } else {
+                    None
+                }, // only save the hex view rect if it's visible, we need to know if it's visible to
+                // determine the cursor position
+                info_view: if !self.fullscreen || self.selected_pane == Pane::View {
+                    Some(info_view_rect)
+                } else {
+                    None
+                }, // only save the info view rect if it's visible, we need to know if it's visible to
+                // determine the cursor position
                 info_view_frame_info,
                 blocks_per_row: self.blocks_per_row,
                 scroll: self.scroll,
@@ -382,12 +450,15 @@ impl Default for App {
             logger: Logger::default(),
             help_list: Self::help_list(&Settings::default().key),
             data: Data::default(),
+            comments: Comments::default(),
             assembly_offsets: Vec::new(),
             assembly_instructions: Vec::new(),
             text_last_searched_string: String::new(),
             info_mode: InfoMode::Text,
             scroll: 0,
             cursor: (0, 0),
+            selected_pane: Pane::Hex,
+            fullscreen: false,
             poll_time: Duration::from_millis(1000),
             needs_to_exit: false,
             screen_size: (0, 0),
@@ -405,8 +476,8 @@ impl Default for App {
                 status_bar: Rect::default(),
                 scroll_bar: Rect::default(),
                 address_view: Rect::default(),
-                hex_view: Rect::default(),
-                info_view: Rect::default(),
+                hex_view: Some(Rect::default()),
+                info_view: Some(Rect::default()),
                 info_view_frame_info: InfoViewFrameInfo::TextView,
                 blocks_per_row: 1,
                 scroll: 0,
