@@ -1,4 +1,4 @@
-use super::{data::Data, log::NotificationLevel, App};
+use super::{data::Data, info_mode::InfoMode, log::NotificationLevel, pane::Pane, App};
 
 pub struct CursorPosition {
     pub cursor: Option<(u16, u16)>,
@@ -167,6 +167,43 @@ impl App {
         }
     }
 
+    pub(super) fn jump_to_fuzzy_comment(
+        &mut self,
+        comment: &str,
+        comments: &[(u64, String)],
+        scroll: usize,
+    ) {
+        if comment.is_empty() {
+            if let Some(comment) = self.comments.iter().nth(scroll) {
+                let (address, _comment) = comment;
+                let log_message = format!("Jumping to comment at {:#X}", address);
+                self.jump_to(*address as usize, false);
+                self.log(NotificationLevel::Debug, &log_message);
+            } else {
+                unreachable!("The scroll should not be greater than the number of comments")
+            }
+            return;
+        } else if comments.is_empty() {
+            self.log(
+                NotificationLevel::Error,
+                "No comments matching the search pattern found",
+            );
+            return;
+        }
+
+        let mut find_iter = comments.iter().skip(scroll);
+        if let Some(comment) = find_iter.next() {
+            let (address, _comment) = comment;
+            self.log(
+                NotificationLevel::Debug,
+                &format!("Jumping to comment at {:#X}", address),
+            );
+            self.jump_to(*address as usize, false);
+        } else {
+            unreachable!("The scroll should not be greater than the number of comments");
+        }
+    }
+
     pub(super) fn jump_to_symbol(&mut self, symbol: &str) {
         if let Some(address) = symbol.strip_prefix("0x") {
             if let Ok(address) = usize::from_str_radix(address, 16) {
@@ -292,6 +329,16 @@ impl App {
         )
     }
 
+    pub(super) fn move_cursor_in_selected_panel(&mut self, dx: isize, dy: isize) {
+        match self.selected_pane {
+            Pane::Hex => self.move_cursor(dx, dy, false),
+            Pane::View => match self.info_mode {
+                InfoMode::Text => self.move_cursor(dx * 2, dy, false),
+                InfoMode::Assembly => self.move_cursor_to_near_instruction(dy),
+            },
+        }
+    }
+
     pub(super) fn move_cursor(&mut self, dx: isize, dy: isize, best_effort: bool) {
         if self.screen_size.1 <= self.vertical_margin {
             return;
@@ -384,6 +431,13 @@ impl App {
         let target_address = self.assembly_instructions[next_instruction_index].file_address();
         self.jump_to(target_address as usize, false);
     }
+
+    pub(super) fn switch_selected_pane(&mut self) {
+        match self.selected_pane {
+            Pane::Hex => self.selected_pane = Pane::View,
+            Pane::View => self.selected_pane = Pane::Hex,
+        }
+    }
 }
 
 #[cfg(test)]
