@@ -18,13 +18,17 @@ impl App {
         match event {
             event::Event::Key(event) if event.kind == event::KeyEventKind::Press => {
                 if event == self.settings.key.up {
-                    self.move_cursor(0, -1, false);
+                    self.move_cursor_in_selected_panel(0, -1);
+                    // self.move_cursor(0, -1, false);
                 } else if event == self.settings.key.down {
-                    self.move_cursor(0, 1, false);
+                    self.move_cursor_in_selected_panel(0, 1);
+                    // self.move_cursor(0, 1, false);
                 } else if event == self.settings.key.left {
-                    self.move_cursor(-1, 0, false);
+                    self.move_cursor_in_selected_panel(-1, 0);
+                    // self.move_cursor(-1, 0, false);
                 } else if event == self.settings.key.right {
-                    self.move_cursor(1, 0, false);
+                    self.move_cursor_in_selected_panel(1, 0);
+                    // self.move_cursor(1, 0, false);
                 } else if event == self.settings.key.next {
                     match self.info_mode {
                         super::info_mode::InfoMode::Text => {
@@ -71,6 +75,10 @@ impl App {
                     self.request_popup_find_text();
                 } else if event == self.settings.key.find_symbol {
                     self.request_popup_find_symbol();
+                } else if event == self.settings.key.edit_comment {
+                    self.request_popup_edit_comment();
+                } else if event == self.settings.key.find_comment {
+                    self.request_popup_find_comment();
                 } else if event == self.settings.key.patch_text {
                     self.request_popup_text();
                 } else if event == self.settings.key.patch_assembly {
@@ -83,6 +91,10 @@ impl App {
                     self.undo();
                 } else if event == self.settings.key.redo {
                     self.redo();
+                } else if event == self.settings.key.change_selected_pane {
+                    self.switch_selected_pane();
+                } else if event == self.settings.key.fullscreen {
+                    self.switch_fullscreen();
                 } else if let KeyCode::Char(c) = event.code {
                     match c {
                         '0'..='9' | 'A'..='F' | 'a'..='f' => {
@@ -275,6 +287,37 @@ impl App {
                     *symbols = self.find_symbols(filter);
                 }
             }
+            Some(PopupState::EditComment { comment, cursor }) => {
+                Self::handle_string_edit(
+                    comment,
+                    cursor,
+                    &event,
+                    None,
+                    None,
+                    true,
+                    &self.settings.key,
+                )?;
+            }
+            Some(PopupState::FindComment {
+                filter,
+                comments,
+                cursor,
+                scroll: _scroll,
+            }) => {
+                let old_filter = filter.clone();
+                Self::handle_string_edit(
+                    filter,
+                    cursor,
+                    &event,
+                    None,
+                    None,
+                    false,
+                    &self.settings.key,
+                )?;
+                if old_filter != *filter || comments.is_empty() {
+                    *comments = self.find_comments(filter);
+                }
+            }
             Some(PopupState::InsertText { text, cursor }) => {
                 Self::handle_string_edit(
                     text,
@@ -425,6 +468,22 @@ impl App {
                             self.jump_to_symbol(location);
                             popup = None;
                         }
+                        Some(PopupState::EditComment {
+                            comment,
+                            cursor: _cursor,
+                        }) => {
+                            self.edit_comment(comment);
+                            popup = None;
+                        }
+                        Some(PopupState::FindComment {
+                            filter,
+                            cursor: _cursor,
+                            comments,
+                            scroll,
+                        }) => {
+                            self.jump_to_fuzzy_comment(filter, comments, *scroll);
+                            popup = None;
+                        }
                         Some(PopupState::SaveAs { path, cursor: _ }) => {
                             self.save_file_as(path)?;
                             popup = None;
@@ -499,6 +558,18 @@ impl App {
                                 Self::handle_popup_scroll(scroll, symbols.len(), None, 1);
                             }
                         }
+                        Some(PopupState::FindComment {
+                            filter: _filter,
+                            comments,
+                            cursor: _cursor,
+                            scroll,
+                        }) => {
+                            if comments.is_empty() {
+                                Self::handle_popup_scroll(scroll, self.comments.len(), None, 1);
+                            } else {
+                                Self::handle_popup_scroll(scroll, comments.len(), None, 1);
+                            }
+                        }
                         Some(PopupState::Log(scroll)) => {
                             Self::handle_popup_scroll(
                                 scroll,
@@ -544,6 +615,14 @@ impl App {
                         }) => {
                             Self::handle_popup_scroll(scroll, symbols.len(), None, -1);
                         }
+                        Some(PopupState::FindComment {
+                            filter: _filter,
+                            comments,
+                            cursor: _cursor,
+                            scroll,
+                        }) => {
+                            Self::handle_popup_scroll(scroll, comments.len(), None, -1);
+                        }
                         Some(PopupState::Log(scroll)) => {
                             Self::handle_popup_scroll(
                                 scroll,
@@ -603,6 +682,14 @@ impl App {
                             }) => {
                                 *scroll = 0;
                             }
+                            Some(PopupState::FindComment {
+                                filter: _,
+                                comments: _,
+                                cursor: _,
+                                scroll,
+                            }) => {
+                                *scroll = 0;
+                            }
                             _ => {}
                         }
                     }
